@@ -1,9 +1,9 @@
-# RCS Status      : $Id: Font.pm,v 1.25 2014/12/27 20:35:14 jv Exp $
+# RCS Status      : $Id: Font.pm,v 1.13 2000-02-04 10:32:30+01 jv Exp $
 # Author          : Johan Vromans
 # Created On      : December 1998
 # Last Modified By: Johan Vromans
-# Last Modified On: Sat Dec 27 21:35:02 2014
-# Update Count    : 468
+# Last Modified On: Fri Feb  4 10:23:08 2000
+# Update Count    : 362
 # Status          : Released
 
 ################ Module Preamble ################
@@ -14,44 +14,107 @@ use strict;
 
 BEGIN { require 5.005; }
 
-use IO qw(File);
+use IO;
 use File::Spec;
-use PostScript::StandardEncoding;
-use PostScript::ISOLatin1Encoding;
 
 use vars qw($VERSION);
-$VERSION = "1.05";
+$VERSION = "1.01";
 
 # If you have the t1disasm program, have $t1disasm point to it.
 # This speeds up the glyph fetching.
-use vars qw($t1disasm);
+# The ttftot42 is used to convert True Type fonts to Type 42.
+use vars qw($t1disasm $ttftot42);
+
+# Adobe StandardEncoding.
+my @StandardEncoding;
+my $StandardEncoding =
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  "space exclam quotedbl numbersign dollar percent ampersand quoteright ".
+  "parenleft parenright asterisk plus comma hyphen period slash zero ".
+  "one two three four five six seven eight nine colon semicolon less ".
+  "equal greater question at A B C D E F G H I J K L M N O P Q R S T U ".
+  "V W X Y Z bracketleft backslash bracketright asciicircum underscore ".
+  "quoteleft a b c d e f g h i j k l m n o p q r s t u v w x y z ".
+  "braceleft bar braceright asciitilde .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef exclamdown cent ".
+  "sterling fraction yen florin section currency quotesingle ".
+  "quotedblleft guillemotleft guilsinglleft guilsinglright fi fl ".
+  ".notdef endash dagger daggerdbl periodcentered .notdef paragraph ".
+  "bullet quotesinglbase quotedblbase quotedblright guillemotright ".
+  "ellipsis perthousand .notdef questiondown .notdef grave acute ".
+  "circumflex tilde macron breve dotaccent dieresis .notdef ring ".
+  "cedilla .notdef hungarumlaut ogonek caron emdash .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef AE .notdef ".
+  "ordfeminine .notdef .notdef .notdef .notdef Lslash Oslash OE ".
+  "ordmasculine .notdef .notdef .notdef .notdef .notdef ae .notdef ".
+  ".notdef .notdef dotlessi .notdef .notdef lslash oslash oe germandbls ".
+  ".notdef .notdef .notdef .notdef";
+
+# Adobe ISOLatin1Encoding.
+my @ISOLatin1Encoding;
+my $ISOLatin1Encoding =
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  "space exclam quotedbl numbersign dollar percent ampersand quoteright ".
+  "parenleft parenright asterisk plus comma minus period slash zero one ".
+  "two three four five six seven eight nine colon semicolon less equal ".
+  "greater question at A B C D E F G H I J K L M N O P Q R S T U V W X ".
+  "Y Z bracketleft backslash bracketright asciicircum underscore ".
+  "quoteleft a b c d e f g h i j k l m n o p q r s t u v w x y z ".
+  "braceleft bar braceright asciitilde .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef .notdef .notdef .notdef ".
+  ".notdef .notdef .notdef .notdef .notdef dotlessi grave acute ".
+  "circumflex tilde macron breve dotaccent dieresis .notdef ring ".
+  "cedilla .notdef hungarumlaut ogonek caron space exclamdown cent ".
+  "sterling currency yen brokenbar section dieresis copyright ".
+  "ordfeminine guillemotleft logicalnot hyphen registered macron degree ".
+  "plusminus twosuperior threesuperior acute mu paragraph ".
+  "periodcentered cedilla onesuperior ordmasculine guillemotright ".
+  "onequarter onehalf threequarters questiondown Agrave Aacute ".
+  "Acircumflex Atilde Adieresis Aring AE Ccedilla Egrave Eacute ".
+  "Ecircumflex Edieresis Igrave Iacute Icircumflex Idieresis Eth Ntilde ".
+  "Ograve Oacute Ocircumflex Otilde Odieresis multiply Oslash Ugrave ".
+  "Uacute Ucircumflex Udieresis Yacute Thorn germandbls agrave aacute ".
+  "acircumflex atilde adieresis aring ae ccedilla egrave eacute ".
+  "ecircumflex edieresis igrave iacute icircumflex idieresis eth ntilde ".
+  "ograve oacute ocircumflex otilde odieresis divide oslash ugrave ".
+  "uacute ucircumflex udieresis yacute thorn ydieresis";
+
+my $trace;
+my $verbose;
+my $error;
 
 sub new {
     my $class = shift;
     my $font = shift;
     my (%atts) = (error => 'die',
 		  format => 'ascii',
-		  verbose => 0, trace => 0, debug => 0,
+		  verbose => 0, trace => 0,
 		  @_);
     my $self = { file => $font };
     bless $self, $class;
 
     return $self unless defined $font;
 
-    $self->{debug}   = $atts{debug};
-    $self->{trace}   = $self->{debug} || $atts{trace};
-    $self->{verbose} = $self->{trace} || $atts{verbose};
-
-    my $error = lc($atts{error});
-    $self->{die} = sub {
-	die(@_)     if $error eq "die";
-	warn(@_)    if $error eq "warn";
-    };
-
+    $trace = lc($atts{trace});
+    $verbose = $trace || lc($atts{verbose});
+    $error = lc($atts{error});
     $atts{format} = "ascii" if lc($atts{format}) eq "pfa";
     $atts{format} = "binary" if lc($atts{format}) eq "pfb";
 
-    $t1disasm = $self->_getexec ("t1disasm") unless defined $t1disasm;
+    $ttftot42 = _getexec ("ttftot42")
+      unless defined $ttftot42;
+    $t1disasm = _getexec ("t1disasm")
+      unless defined $t1disasm;
 
     eval {
 
@@ -61,13 +124,13 @@ sub new {
 	$self->{format} = "ascii";
 	if ( lc($atts{format}) eq "asm" ) {
 	    print STDERR ($self->{file}, ": Converting to ASM format\n")
-	      if $self->{verbose};
+	      if $verbose;
 	    $self->{data} = $self->_pfa2asm;
 	    $self->{format} = "asm";
 	}
 	elsif ( lc($atts{format}) eq "binary" ) {
 	    print STDERR ($self->{file}, ": Converting to Binary format\n")
-	      if $self->{verbose};
+	      if $verbose;
 	    $self->{data} = $self->_pfa2pfb;
 	    $self->{format} = "binary";
 	}
@@ -75,7 +138,8 @@ sub new {
     };
 
     if ( $@ ) {
-	$self->_die($@);
+	die ($@)  unless $error eq "warn";
+	warn ($@) unless $error eq "ignore";
 	return undef;
     }
 
@@ -84,6 +148,7 @@ sub new {
 
 sub FileName	{ $_[0]->{file};      }
 sub FontName	{ $_[0]->{name};      }
+sub FontData	{ ${$_[0]->{data}};   }
 sub FamilyName	{ $_[0]->{family};    }
 sub FontType	{ $_[0]->{type};      }
 sub Version	{ $_[0]->{version};   }
@@ -91,18 +156,7 @@ sub ItalicAngle	{ $_[0]->{italic};    }
 sub isFixedPitch{ $_[0]->{fixed};     }
 sub Weight	{ $_[0]->{weight};    }
 sub FontMatrix	{ $_[0]->{fontmatrix};}
-sub FontBBox	{ $_[0]->{fontbbox};  }
-sub DataFormat  { $_[0]->{dataformat} }
-
-sub FontData	{
-    my ($self, $format) = @_;
-    if ( defined $format ) {
-	# Not yet supported!
-	return ${$self->_cvtinternal($format)};
-    }
-    $self->{data} = $self->_cvtinternal unless exists $self->{data};
-    ${$self->{data}};
-}
+sub DataFormat  { $_[0]->{format};    }
 
 sub FontGlyphs {
     my $self = shift;
@@ -122,20 +176,24 @@ sub EncodingVector {
     return $enc if ref($enc) eq "ARRAY";
     # Return private copy for the standard encodings.
     if ( $enc eq "StandardEncoding" ) {
-	return scalar PostScript::StandardEncoding->array;
+	return StandardEncoding();
     }
     elsif ( $enc eq "ISOLatin1Encoding" ) {
-	return scalar PostScript::ISOLatin1Encoding->array;
+	return ISOLatin1Encoding();
     }
     undef;
 }
 
 sub StandardEncoding {
-    return scalar PostScript::StandardEncoding->array;
+    @StandardEncoding = split(' ', $StandardEncoding)
+      unless @StandardEncoding;
+    \@StandardEncoding;
 }
 
 sub ISOLatin1Encoding {
-    return scalar PostScript::ISOLatin1Encoding->array;
+    @ISOLatin1Encoding = split(' ', $ISOLatin1Encoding)
+      unless @ISOLatin1Encoding;
+    \@ISOLatin1Encoding;
 }
 
 sub _loadfont ($) {
@@ -148,61 +206,58 @@ sub _loadfont ($) {
     my $fh = new IO::File;	# font file
     my $sz = -s $fn;	# file size
 
-    $fh->open ($fn) || $self->_die("$fn: $!\n");
-    print STDERR ("$fn: Loading font file\n") if $self->{verbose};
+    $fh->open ($fn) || die ("$fn: $!\n");
+    print STDERR ("$fn: Loading font file\n") if $verbose;
 
     # Read in the font data.
-    binmode($fh);		# (Some?) Windows need this
     my $len = 0;
+    unless ( ($len = $fh->sysread ($data, 4, 0)) == 4 ) {
+	die ("$fn: Expecting $sz bytes, got $len bytes\n");
+    }
+
+    $self->{origdataformat} = 'pfa';
+    if ( $data eq "\0\1\0\0" ) {
+	#### WARNING: This is Unix specific! ####
+	my $cmd = $ttftot42 || $PostScript::FontMetrics::ttftot42;
+	my $f = _qtfn($fn);
+	if ( $cmd ) {
+	    $cmd .= " -fc $f 2>>/dev/null |";
+	    print STDERR ("$fn: Converting True Type font to Type 42\n")
+	      if $verbose;
+	}
+	else {
+	    die ("$fn: Cannot convert True Type font\n");
+	}
+
+	$fh->close;
+	$type = "t";
+	print STDERR ("+ $cmd\n") if $trace;
+	$fh->open ($cmd) || die ("$cmd: $!\n");;
+	$sz = -1;
+	$len = 0;
+	$self->{origdataformat} = 'ttf';
+    }
+
     while ( $fh->sysread ($data, 32768, $len) > 0 ) {
 	$len = length ($data);
     }
     $fh->close;
-    $self->_die("$fn: Expecting at least 4 bytes, got ",
-		length($data), " bytes\n")
-      unless length($data) >= 4;
-
-    $self->{dataformat} = 'ps';
-    if ( substr($data,0,4) eq "\0\1\0\0" || substr($data, 0, 4) eq "OTTO" ) {
-	# For the time being, Font::TTF is optional. Be careful.
-	eval {
-	    require PostScript::Font::TTtoType42;
-	};
-	if ( $@ ) {
-	    $self->_die("$fn: Cannot convert True Type font\n");
-	    return undef;
-	}
-	my $wrapper =
-	  new PostScript::Font::TTtoType42:: ($fn,
-					      verbose => $self->{verbose},
-					      trace   => $self->{trace},
-					      debug   => $self->{debug},
-					     );
-	$type = "t";
-	$data = $wrapper->as_string;
-	$self->{t42wrapper} = $wrapper;
-	$self->{dataformat} = "type42";
-	$self->{encoding} = "StandardEncoding";
-    }
-    else {
-	# Make ref.
-	$data = \"$data";		#";
-    }
-
-    print STDERR ("Read $len bytes from $fn\n") if $self->{trace};
-    $self->_die("$fn: Expecting $sz bytes, got $len bytes\n")
+    print STDERR ("Read $len bytes from $fn\n") if $trace;
+    die ("$fn: Expecting $sz bytes, got $len bytes\n")
       if $sz > 0 && $sz != $len;
 
+    # Make ref.
+    $data = \"$data";		#";
+
     # Convert .pfb encoded font data.
     if ( $$data =~ /^\200[\001-\003]/ ) {
-	print STDERR ("$fn: Converting to ASCII format\n") if $self->{verbose};
+	print STDERR ("$fn: Converting to ASCII format\n") if $verbose;
 	$data = $self->_pfb2pfa ($data);
-	$self->{dataformat} = 'pfa';
+	$self->{origdataformat} = 'pfb';
     }
     # Otherwise, must be straight PostScript.
     elsif ( $$data !~ /^%!/ ) {
-	$self->_die("$fn: Not a recognizable font file\n");
-	return undef;
+	die ("$fn: Not a recognizable font file\n");
     }
 
     # Normalise line endings.
@@ -243,9 +298,6 @@ sub _loadfont ($) {
     if ( $$data =~ /\/FontMatrix\s*\[\s*(\d+(?:\.\d*)?)\s+(\d+(?:\.\d*)?)\s+(\d+(?:\.\d*)?)\s+(\d+(?:\.\d*)?)\s+(\d+(?:\.\d*)?)\s+(\d+(?:\.\d*)?)\s*\]/ ) {
 	$self->{fontmatrix} = [$1,$2,$3,$4,$5,$6];
     }
-    if ( $$data =~ /\/FontBBox\s*\{\s*(-?\d+(?:\.\d*)?)\s+(-?\d+(?:\.\d*)?)\s+(-?\d+(?:\.\d*)?)\s+(-?\d+(?:\.\d*)?)\s*\}/ ) {
-	$self->{fontbbox} = [$1,$2,$3,$4];
-    }
     $self;
 }
 
@@ -255,12 +307,6 @@ sub _qtfn ($) {
     "'".$f."'";
 }
 
-sub _cvtinternal {
-    my ($self, $format) = @_;
-    return $self->{data} if $format eq $self->{format};
-    undef;
-}
-
 sub _pfb2pfa ($;$) {
     my ($self, $data) = @_;	# NOTE: data is a ref!
     my $newdata = "";		# NOTE: will return a ref
@@ -281,7 +327,7 @@ sub _pfb2pfa ($;$) {
     my $bin = "";		# accumulated unprocessed binary segments
     my $addbin = sub {		# binary segment processor
 	print STDERR ("Processing binary segment, ",
-		      length($bin), " bytes\n") if $self->{trace};
+		      length($bin), " bytes\n") if $trace;
 	($bin = uc (unpack ("H*", $bin))) =~ s/(.{64})/$1\n/g;
 	$newdata .= $bin;
 	$newdata .= "\n" unless $newdata =~ /\n$/;
@@ -294,7 +340,7 @@ sub _pfb2pfa ($;$) {
 	last if $$data =~ /^\200\003/; # EOF indicator
 
 	# Get font segment.
-	$self->_die($self->{file}, ": Invalid font segment format\n")
+	die ($self->{file}, ": Invalid font segment format\n")
 	  unless ($type, $info) = $$data =~ /^\200([\001-\002])(....)/s;
 
 	my $len = unpack ("V", $info);
@@ -306,12 +352,12 @@ sub _pfb2pfa ($;$) {
 	if ( ord($type) == 1 ) {	# ASCII segment
 	    $addbin->() if $bin ne "";
 	    print STDERR ($self->{file}, ": ASCII segment, $len bytes\n")
-	      if $self->{trace};
+	      if $trace;
 	    $newdata .= $seg;
 	}
 	else { # ord($type) == 2	# Binary segment
 	    print STDERR ($self->{file}, ": Binary segment, $len bytes\n")
-	      if $self->{trace};
+	      if $trace;
 	    $bin .= $seg;
 	}
     }
@@ -356,11 +402,18 @@ sub _pfa2asm ($;$) {
 	#### WARNING: This is Unix specific! ####
 	my $cmd = "$t1disasm $fn";
 	if ( $self->{type} eq 't' ) {
-	    $self->_die($self->{file},
-			": Logic error -- Cannot convert True Type font\n");
+	    if ( $ttftot42 ) {
+		$cmd = "$ttftot42 -fc $fn | $t1disasm";
+	    }
+	    elsif ( $PostScript::FontMetrics::ttftot42 ) {
+		$cmd = "$PostScript::FontMetrics::ttftot42 -fc $fn | $t1disasm";
+	    }
+	    else {
+		die ($self->{file}, ": Cannot convert True Type font\n");
+	    }
 	}
 
-	print STDERR ("+ $cmd |\n") if $self->{trace};
+	print STDERR ("+ $cmd |\n") if $trace;
 	my $fh = new IO::File ("$cmd |");
 	local ($/);
 	my $newdata = <$fh>;
@@ -420,17 +473,9 @@ sub _getglyphnames ($;$) {
     my ($self, $data) = @_;
     my @glyphs = ();
 
-    print STDERR ($self->{file}, ": Getting glyph info\n") if $self->{verbose};
-
     $data = $self->{data} unless defined $data;
 
-    if ( $self->{dataformat} eq "type42" ) {
-	my $g = $self->{t42wrapper}->glyphnames;
-	print STDERR ($self->{file}, ": Number of glyphs = ",
-		      scalar(@$g), "\n")
-	  if $self->{verbose};
-	return $g;
-    }
+    print STDERR ($self->{file}, ": Getting glyph info\n") if $verbose;
 
     if ( $self->{format} eq "binary" ) {
 	$data = $self->_pfb2pfa ($data);
@@ -449,16 +494,11 @@ sub _getglyphnames ($;$) {
 	}
     }
 
-#    while ( $data =~ m;((^\d*\s*/([.\w]+))|(\bend\b)).*\n;mg ) {
-    while ( $data =~ m;(/([.\w]+)\b|\bend\b);mg ) {
+    while ( $data =~ m;((^\d*\s*/([.\w]+))|(\bend\b)).*\n;mg ) {
 	last if $1 eq "end";
-	push (@glyphs, $2);
+	push (@glyphs, $3);
     }
 
-    print STDERR ($self->{file}, ": Number of glyphs = ",
-		  scalar(@glyphs), "\n")
-      if $self->{verbose};
-
     \@glyphs;
 }
 
@@ -466,8 +506,7 @@ sub _getencoding ($;$) {
     my ($self, $data) = @_;
     my @glyphs = ();
 
-    print STDERR ($self->{file}, ": Getting encoding info\n")
-      if $self->{verbose};
+    print STDERR ($self->{file}, ": Getting encoding info\n") if $verbose;
 
     $data = $self->{data} unless defined $data;
     $data = $$data;		# deref
@@ -483,10 +522,10 @@ sub _getencoding ($;$) {
 	$enc =~ s/^\s+//;
 	$enc =~ s/\s+$//;
 	$enc =~ s/\s+/ /g;
-	if ( $enc eq PostScript::StandardEncoding->string ) {
+	if ( $enc eq $StandardEncoding ) {
 	    $enc = "StandardEncoding"
 	}
-	elsif ( $enc eq PostScript::ISOLatin1Encoding->string ) {
+	elsif ( $enc eq $ISOLatin1Encoding ) {
 	    $enc = "ISOLatin1Encoding"
 	}
 	else {
@@ -503,10 +542,10 @@ sub _getencoding ($;$) {
 	while ( $enc =~ m;dup (\d+)\s*/(\S+) put;g ) {
 	    $enc[$1] = $2;
 	}
-	if ( "@enc" eq PostScript::StandardEncoding->string ) {
+	if ( "@enc" eq $StandardEncoding ) {
 	    $enc = "StandardEncoding"
 	}
-	elsif ( "@enc" eq PostScript::ISOLatin1Encoding->string ) {
+	elsif ( "@enc" eq $ISOLatin1Encoding ) {
 	    $enc = "ISOLatin1Encoding"
 	}
 	else {
@@ -519,32 +558,20 @@ sub _getencoding ($;$) {
 }
 
 sub _getexec ($) {
-    my ($self, $exec) = @_;
+    my ($exec) = @_;
     foreach ( File::Spec->path ) {
 	if ( -x "$_/$exec" ) {
-	    print STDERR ("Using $_/$exec\n") if $self->{verbose};
+	    print STDERR ("Using $_/$exec\n") if $verbose;
 	    return "$_/$exec";
 	}
 	elsif ( -x "$_/$exec.exe" ) {
-	    print STDERR ("Using $_/$exec.exe\n") if $self->{verbose};
+	    print STDERR ("Using $_/$exec.exe\n") if $verbose;
 	    return "$_/$exec.exe";
 	}
     }
     ''
 }
 
-sub _die {
-    my ($self, @msg) = @_;
-    $self->{die}->(@msg);
-}
-
-# PostScript::TTtoType42 is actually an Font::TTF::Font object.
-# Font::TTF::Font uses cyclic structures, so we need this.
-sub DESTROY {
-    my $self = shift;
-    $self->{t42wrapper}->DESTROY if $self->{t42wrapper};
-}
-
 1;
 
 __END__
@@ -572,9 +599,13 @@ how weird the font information is stored.
 The input font file can be encoded in ASCII (so-called C<.pfa>
 format), or binary (so-called C<.pfb> format).
 
-If you have Martin Hosken's Font::TTF package installed,
-PostScript::Font can also handle True Type fonts. They are converted
-internally to Type 42 format.
+True Type fonts are understood as well, they are converted internally
+to Type 42 format. Currently this requires an external program,
+I<ttftot42>. This program will be used automatically if it can be
+located in the execution C<PATH>. Alternatively, you can set the
+variable C<$PostScript::Font::ttftot42> (or
+C<$PostScript::FontMetrics::ttftot42>) to the name of the actual
+program. See also L<EXTERNAL PROGRAMS>.
 
 =head1 CONSTRUCTOR
 
@@ -592,11 +623,8 @@ The constructor will read the file and parse its contents.
 
 =item error => [ 'die' | 'warn' | 'ignore' ]
 
-B<DEPRECATED>. Please use 'eval { ... }' to intercept errors.
-
 How errors must be handled. Default is to call die().
 In any case, new() returns a undefined result.
-Setting 'error' to 'ignore' may cause surprising results.
 
 =item format => [ 'ascii' | 'pfa' | 'binary' | 'pfb' ]
 
@@ -668,10 +696,6 @@ To find the font scale, use
 
     int(1/$font->FontMatrix->[0])
 
-=item FontBBox
-
-The font bounding box as a reference to an anonymous array with the 4 values.
-
 =item DataFormat
 
 The format in which the data is kept internally. See the B<format> option.
@@ -724,21 +748,47 @@ fonts do not require disassembly to get at the glyph list.
 Returns a reference to an array that contains all the glyphs names for
 Adobe's Standard Encoding.
 
-If this is the only thing you want from this module, use
-C<PostScript::StandardEncoding> instead.
-
 =item ISOLatin1Encoding
 
 Returns a reference to an array that contains all the glyphs names for
 ISO-8859-1 (ISO Latin-1) encoding.
 
-If this is the only thing you want from this module, use
-C<PostScript::ISOLatin1Encoding> instead.
-
 =back
 
 =head1 EXTERNAL PROGRAMS
 
+Two external programs can be used by this package.
+
+I<ttftot42> is required when True Type fonts must be handled. It is
+called as follows:
+
+    ttftot42 -fc filename
+
+This invocation will write the Type 42 version of the True Type font to
+standard output.
+
+I<ttftot42> can be found on http://ftp.giga.or.at/pub/nih/ttftot42
+
+An alternative, but not encouraged, way to handle True Type fonts is
+by converting them to Type 1 fonts. An excellent converter, I<ttf2pt1>,
+can be used for this. To use this program, create a fake I<ttftot42>
+script and set variable $PostScript::Font::ttftot42 to the name of
+this script. The script should contain something like this:
+
+    $!/bin/sh
+    shift	# get rid of '-fc' argument
+    exec ttf2pt1 -ef "$@" - 2>/dev/null
+
+The redirection of error output to /dev/null is necessary. since the
+program is quite verbose. Unfortunately, error messages will disappear
+as well.
+
+I<ttf2pt1> can be found on http://www.netspace.net.au/~mark/ttf2pt1
+
+B<Note:> the resultant Type1 font is not a real conversion, but a
+(very similar) imitation of the original True Type font. Small
+differences may be noticable depending on the font quality.
+
 I<t1disasm> can be used to speed up the fetching of the list of font
 glyphs from Type 1 fonts. It is called as follows:
 
@@ -751,18 +801,18 @@ places.
 
 =head1 KNOWN BUGS
 
-Invoking external programs (like I<t1disasm>) is guaranteed to work on
-Unix only.
+Invoking external programs (I<t1disasm>, I<ttftot42>) is guaranteed to
+work on Unix only.
 
 =head1 SEE ALSO
 
 =over 4
 
-=item http://partners.adobe.com/asn/developer/PDFS/TN/T1_SPEC.PDF
+=item http://www.adobe.com/supportservice/devrelations/PDFS/TN/T1_SPEC.PDF
 
 The specification of the Type 1 font format.
 
-=item http://partners.adobe.com/asn/developer/PDFS/TN/5012.Type42_Spec.pdf
+=item http://www.adobe.com/supportservice/devrelations/PDFS/TN/5012.Type42_Spec.pdf
 
 The specification of the Type 42 font format.
 
@@ -770,7 +820,7 @@ The specification of the Type 42 font format.
 
 The True Type reference manual.
 
-=item http://partners.adobe.com/asn/developer/PDFS/TN/5004.AFM_Spec.pdf
+=item http://www.adobe.com/supportservice/devrelations/PDFS/TN/5004.AFM_Spec.pdf
 
 The specification of the Adobe font metrics file format.
 
@@ -782,7 +832,7 @@ Johan Vromans, Squirrel Consultancy <jvromans@squirrel.nl>
 
 =head1 COPYRIGHT and DISCLAIMER
 
-This program is Copyright 2014,2000,1998 by Squirrel Consultancy. All
+This program is Copyright 2000,1998 by Squirrel Consultancy. All
 rights reserved.
 
 This program is free software; you can redistribute it and/or modify
