@@ -1,9 +1,9 @@
-# RCS Status      : $Id: FontInfo.pm,v 1.12 2003-10-23 14:12:27+02 jv Exp $
+# RCS Status      : $Id: FontInfo.pm,v 1.7 2000-02-04 10:32:30+01 jv Exp $
 # Author          : Johan Vromans
 # Created On      : December 1998
 # Last Modified By: Johan Vromans
-# Last Modified On: Thu Oct 23 14:12:25 2003
-# Update Count    : 57
+# Last Modified On: Fri Feb  4 10:23:41 2000
+# Update Count    : 44
 # Status          : Released
 
 ################ Module Preamble ################
@@ -14,38 +14,35 @@ use strict;
 
 BEGIN { require 5.005; }
 
-use IO qw(File);
+use IO;
 
 use vars qw($VERSION);
-$VERSION = "1.05";
+$VERSION = "1.03";
+
+my $trace;
+my $verbose;
+my $error;
 
 sub new {
     my $class = shift;
     my $font = shift;
     my (%atts) = (error => 'die',
-		  verbose => 0, trace => 0, debug => 0,
+		  verbose => 0, trace => 0,
 		  @_);
     my $self = { file => $font };
     bless $self, $class;
 
-    return $self unless defined $font;
-
-    $self->{debug}   = $atts{debug};
-    $self->{trace}   = $self->{debug} || $atts{trace};
-    $self->{verbose} = $self->{trace} || $atts{verbose};
-
-    my $error = lc($atts{error});
-    $self->{die} = sub {
-	die(@_)     if $error eq "die";
-	warn(@_)    if $error eq "warn";
-    };
+    $trace = lc($atts{trace});
+    $verbose = $trace || lc($atts{verbose});
+    $error = lc($atts{error});
 
     eval {
 	$self->_loadinfo;
     };
 
     if ( $@ ) {
-	$self->_die($@);
+	die ($@)  unless $error eq "warn";
+	warn ($@) unless $error eq "ignore";
 	return undef;
     }
 
@@ -54,7 +51,6 @@ sub new {
 
 sub FileName	{ my $self = shift; $self->{file};    }
 sub FontName	{ my $self = shift; $self->{name};    }
-sub FullName	{ my $self = shift; $self->{fullname};}
 sub InfoData	{ my $self = shift; $self->{data};    }
 sub FontFamily	{ my $self = shift; $self->{family};  }
 sub Version	{ my $self = shift; $self->{version}; }
@@ -72,8 +68,8 @@ sub _loadinfo ($) {
 	my $fh = new IO::File;	# font file
 	my $sz = -s $fn;	# file size
 
-	$fh->open ($fn) || $self->_die("$fn: $!\n");
-	print STDERR ("$fn: Loading INF file\n") if $self->{verbose};
+	$fh->open ($fn) || die ("$fn: $!\n");
+	print STDERR ("$fn: Loading INF file\n") if $verbose;
 
 	# Read in the inf data.
 	my $len = 0;
@@ -81,20 +77,19 @@ sub _loadinfo ($) {
 	    $len = length ($data);
 	}
 	$fh->close;
-	print STDERR ("Read $len bytes from $fn\n") if $self->{trace};
-	$self->_die("$fn: Expecting $sz bytes, got $len bytes\n") unless $sz == $len;
+	print STDERR ("Read $len bytes from $fn\n") if $trace;
+	die ("$fn: Expecting $sz bytes, got $len bytes\n") unless $sz == $len;
 
 	# Normalise line endings.
 	$data =~ s/\015\012?/\n/g;
 
 	if ( $data !~ /^FontName\s+\(\S+\)$/m ) {
-	    $self->_die("$fn: Not a recognizable INF file\n");
+	    die ("$fn: Not a recognizable INF file\n");
 	}
 
     };
 
     $self->{name}    = $1 if $data =~ /^FontName\s+\((\S+)\)$/mi;
-    $self->{fullname}= $1 if $data =~ /^FullName\s+\((.+?)\)$/mi;
     $self->{family}  = $1 if $data =~ /^FamilyName\s+\((.+)\)$/mi;
     $self->{version} = $1 if $data =~ /^Version\s+\((.+)\)$/mi;
     $self->{pcprefix}= lc($1)
@@ -104,11 +99,6 @@ sub _loadinfo ($) {
     $self;
 }
 
-sub _die {
-    my ($self, @msg) = @_;
-    $self->{die}->(@msg);
-}
-
 1;
 
 __END__
@@ -145,11 +135,8 @@ The constructor will read the file and parse its contents.
 
 =item error => [ 'die' | 'warn' | 'ignore' ]
 
-B<DEPRECATED>. Please use 'eval { ... }' to intercept errors.
-
 How errors must be handled. Default is to call die().
 In any case, new() returns a undefined result.
-Setting 'error' to 'ignore' may cause surprising results.
 
 =item verbose => I<value>
 
@@ -175,17 +162,13 @@ information could not be found in the file.
 
 =item FileName
 
-The name of the file, e.g. 'tir_____.inf'.
+The name of the file, e.g. 'tir_____.afm'.
 
 =item FontName
 
 The name of the font, e.g. 'Times-Roman'.
 
-=item FullName
-
-The full name of the font, e.g. 'Times Roman'.
-
-=item FontFamily
+=item FamilyName
 
 The family name of the font, e.g. 'Times'.
 
@@ -209,7 +192,7 @@ Johan Vromans, Squirrel Consultancy <jvromans@squirrel.nl>
 
 =head1 COPYRIGHT and DISCLAIMER
 
-This program is Copyright 2003,1998 by Squirrel Consultancy. All
+This program is Copyright 2000,1998 by Squirrel Consultancy. All
 rights reserved.
 
 This program is free software; you can redistribute it and/or modify
