@@ -1,8 +1,8 @@
-# RCS Status      : $Id: Resources.pm,v 1.12 2004/12/18 16:40:52 jv Exp $# Author          : Johan Vromans
+# RCS Status      : $Id: Resources.pm,v 1.7 2000-02-04 10:32:30+01 jv Exp $# Author          : Johan Vromans
 # Created On      : Januari 1999
 # Last Modified By: Johan Vromans
-# Last Modified On: Thu Oct 23 14:11:52 2003
-# Update Count    : 187
+# Last Modified On: Fri Feb  4 10:23:29 2000
+# Update Count    : 182
 # Status          : Released
 
 ################ Module Preamble ################
@@ -13,12 +13,12 @@ use strict;
 
 BEGIN { require 5.005; }
 
-use IO qw(File);
+use IO;
 use File::Basename;
 use File::Spec;
 
 use vars qw($VERSION);
-$VERSION = "1.03";
+$VERSION = "1.01";
 
 my $ResourcePath = ".";		# default standard resource path
 my $defupr = "PSref.upr";	# principal resource file
@@ -283,7 +283,7 @@ sub _loadFontAFM ($) {
 
 	# PostScriptName=the/file.afm
 	if ( $line =~ /^([^=]+)=(.*)$/ ) {
-	    $afm->{$1} = $rscidx.$2 unless $afm->{$1};
+	    $afm->{$1} = $rscidx.$2;
 	    next;
 	}
 	warn ($fn, "[$.]: Invalid FontAFM entry\n")
@@ -330,7 +330,7 @@ sub _loadFontOutline ($) {
 
 	# PostScriptName=the/file.pfa
 	if ( $line =~ /^([^=]+)=(.*)$/ ) {
-	    $pfa->{$1} = $rscidx.$2 unless $pfa->{$1};
+	    $pfa->{$1} = $rscidx.$2;
 	    next;
 	}
 	warn ($fn, "[$.]: Invalid FontOutline entry\n")
@@ -359,11 +359,11 @@ __END__
 
 =head1 NAME
 
-PostScript::Resources - module to fetch data from Unix PostScript Resource 'C<.upr>' files
+PostScript::FontResources - module to fetch data from Unix PostScript Resource 'C<.upr>' files
 
 =head1 SYNOPSIS
 
-  my $rsc = new PostScript::Resources (options);
+  my $rsc = new PostScript::FontResources (options);
   print STDOUT $rsc->FontAFM ("Times-Roman"), "\n";
 
 =head1 DESCRIPTION
@@ -484,7 +484,7 @@ Your mileage on other platforms may vary.
 
 =over 4
 
-=item http://partners.adobe.com/asn/developer/PDFS/TN/DPS.refmanuals.TK.pdf
+=item http://www.adobe.com/supportservice/devrelations/PDFS/TN/DPS.refmanuals.TK.pdf
 
 The specification of the Adobe Display PostScript Toolkit for X. The
 format of the font resources file is described in appendix A of this
